#--------------------------------------------------------------------------
#
#   ALHM - Player
#
#--------------------------------------------------------------------------

from albow.resource import get_image, get_font, get_sound
from albow.image_array import get_image_array

from constants import *
from functions import *

class Player(object):

    body = get_image("princess.png")
    body_dead = get_image("princess-defeated.png")
    eyes = get_image_array("princess-eyes.png", 4)
    xoffset = 30
    yoffset = 60
    
    start_cc = (5, 2)
    speed = 150
    
    def __init__(self, level):
        self.position = list(level.cell_centre(self.start_cc))
        self.eye_direction = RIGHT
        self.moving_direction = None
        self.health = 10
    
    def draw(self, surf):
        px, py = self.position
        x = px - self.xoffset
        y = py - self.yoffset
        if self.health > 0:
            surf.blit(self.body, (x, y))
            surf.blit(self.eyes[self.eye_direction], (x + 20, y + 38))
        else:
            surf.blit(self.body_dead, (px - self.yoffset, py - self.xoffset))
    
    def start_moving(self, dir):
        self.moving_direction = dir
        self.eye_direction = dir ^ 2
    
    def stop_moving(self, dir):
        if self.moving_direction == dir:
            self.moving_direction = None
    
    def begin_frame(self, level, dt):
        self.update_position(level, dt)
        self.check_traps(level)
    
    def update_position(self, level, dt):
        dir = self.moving_direction
        if dir is not None:
            pos = self.position
            cc = level.cc_containing(pos)
            cell = level.get_cell(cc)
            if cell:
                pos_ahead = add(pos, scale(50, dirvec[dir]))
                cc_ahead = level.cc_containing(pos_ahead)
                if cc_ahead == cc or cell.connected[dir]:
                    self.position = add(pos, scale(dt * self.speed, dirvec[dir]))
    
    def check_traps(self, level):
        p = self.position
        for trap in level.traps:
            if trap.bounds.collidepoint(p):
                trap.trample(level)
    
    def sting(self, level):
        self.health -= 1
        if self.health == 0:
            level.game_outcome = -1

    def activation_rect(self):
        r = self.body.get_rect()
        r.center = self.position
        return r
